summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2010-03-17 07:40:58 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2010-03-17 07:42:04 -0500
commit844a3c050c440480032226bee8ae9cf0ce379116 (patch)
treeaa9cacc78b2141fea3f91fb2a4765bab0b1fd176 /png.h
parentb07e8568eeeeb7000d5ecc00b6d640b212249e6f (diff)
downloadlibpng-844a3c050c440480032226bee8ae9cf0ce379116.tar.gz
[devel] Bump to version libpng-1.5.0beta16
Diffstat (limited to 'png.h')
-rw-r--r--png.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/png.h b/png.h
index e8fb2cfc7..91c4c28cb 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.0beta15 - March 17, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.0beta15 - March 17, 2010: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -138,7 +138,7 @@
* 1.4.1rc01 14 10401 14.so.14.1[.0]
* 1.4.1beta04-12 14 10401 14.so.14.1[.0]
* 1.4.1 14 10401 14.so.14.1[.0]
- * 1.5.0beta01-15 15 10500 15.so.15.0[.0]
+ * 1.5.0beta01-16 15 10500 15.so.15.0[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -170,7 +170,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.0beta15, March 17, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -288,7 +288,7 @@
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.0beta15 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -344,9 +344,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.0beta15"
+#define PNG_LIBPNG_VER_STRING "1.5.0beta16"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.0beta15 - March 17, 2010\n"
+ " libpng version 1.5.0beta16 - March 17, 2010\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -359,7 +359,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 15
+#define PNG_LIBPNG_VER_BUILD 16
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -782,7 +782,7 @@ typedef PNG_CALLBACK(void, *png_free_ptr, (png_structp, png_voidp),);
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_5_0beta15;
+typedef png_structp version_1_5_0beta16;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.0beta15 - March 17, 2010
+ * libpng version 1.5.0beta16 - March 17, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.0beta15 - March 17, 2010: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.0beta16 - March 17, 2010: Glenn
* See also "Contributing Authors", below.
*
@@ -170,7 +170,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.0beta15, March 17, 2010, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.0beta16, March 17, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -288,7 +288,7 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.0beta15 are Y2K compliant. It is my belief that earlier
+ * upward through 1.5.0beta16 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*